@@ -26,6 +26,7 @@ namespace xsimd
         using value_type = bool;
         static constexpr std::size_t size = 2;
         using batch_type = batch<int64_t, 2>;
+        static constexpr std::size_t align = 16;
     };
 
     template <>
@@ -68,6 +69,7 @@ namespace xsimd
         using value_type = int64_t;
         static constexpr std::size_t size = 2;
         using batch_bool_type = batch_bool<int64_t, 2>;
+        static constexpr std::size_t align = 16;
     };
 
     template <>
@@ -150,8 +152,6 @@ namespace xsimd
 
     batch<int64_t, 2> operator<<(const batch<int64_t, 2>& lhs, int32_t rhs);
     batch<int64_t, 2> operator>>(const batch<int64_t, 2>& lhs, int32_t rhs);
-    batch<int64_t, 2> operator<<(const batch<int64_t, 2>& lhs, const batch<int64_t, 2>& rhs);
-    batch<int64_t, 2> operator>>(const batch<int64_t, 2>& lhs, const batch<int64_t, 2>& rhs);
 
     /********************
      * helper functions *
@@ -577,22 +577,6 @@ namespace xsimd
     {
         return _mm_srli_epi64(lhs, rhs);
     }
-
-    inline batch<int64_t, 2> operator<<(const batch<int64_t, 2>& lhs, const batch<int64_t, 2>& rhs)
-    {
-        return batch<int64_t, 2>{
-            lhs[0] << rhs[0],
-            lhs[1] << rhs[1]
-            };
-    }
-
-    inline batch<int64_t, 2> operator>>(const batch<int64_t, 2>& lhs, const batch<int64_t, 2>& rhs)
-    {
-        return batch<int64_t, 2>{
-            lhs[0] >> rhs[0],
-            lhs[1] >> rhs[1]
-            };
-    }
 }
 
 #endif
